@@ -61,7 +61,9 @@ class TestStandardise:
         (
             ('TRAV35*01', 'TRAV35*01', True),
             ('TRAV35*03', None, True),
-            ('TRAV35*03', 'TRAV35*03', False)
+            ('TRAV35*03', 'TRAV35*03', False),
+            ('TRAV35', 'TRAV35', True),
+            ('TRAV8-7', None, True)
         )
     )
     def test_enforce_functional(self, gene, expected, enforce_functional):
